@@ -1,9 +1,7 @@
 package Test::BDD::Cucumber::Model::Step;
-BEGIN {
-  $Test::BDD::Cucumber::Model::Step::VERSION = '0.01'; # TRIAL
-}
-
-use Moose;
+$Test::BDD::Cucumber::Model::Step::VERSION = '0.60'; # TRIAL
+use Moo;
+use Types::Standard qw( Str ArrayRef InstanceOf );
 
 =head1 NAME
 
@@ -11,7 +9,7 @@ Test::BDD::Cucumber::Model::Step - Model to represent a step in a scenario
 
 =head1 VERSION
 
-version 0.01
+version 0.60
 
 =head1 DESCRIPTION
 
@@ -25,7 +23,7 @@ The text of the step, once Scenario Outlines have been applied
 
 =cut
 
-has 'text' => ( is => 'rw', isa => 'Str' );
+has 'text' => ( is => 'rw', isa => Str );
 
 =head2 verb
 
@@ -36,8 +34,8 @@ that appeared in the physical file - this will sometimes be C<and>.
 
 =cut
 
-has 'verb' => ( is => 'rw', isa => 'Str' );
-has 'verb_original' => ( is => 'rw', isa => 'Str' );
+has 'verb'          => ( is => 'rw', isa => Str );
+has 'verb_original' => ( is => 'rw', isa => Str );
 
 =head2 line
 
@@ -45,7 +43,7 @@ The corresponding L<Test:BDD::Cucumber::Model::Line>
 
 =cut
 
-has 'line' => ( is => 'rw', isa => 'Test::BDD::Cucumber::Model::Line' );
+has 'line' => ( is => 'rw', isa => InstanceOf['Test::BDD::Cucumber::Model::Line'] );
 
 =head2 data
 
@@ -56,14 +54,36 @@ hashrefs for a data table.
 
 has 'data' => ( is => 'rw' );
 
+=head2 data_as_strings
+
+An arrayref of strings containing the original step's data, for printing out
+by harnesses
+
+=cut
+
+has 'data_as_strings' => (
+    is      => 'rw',
+    default => sub { [] },
+    isa     => ArrayRef[Str]
+);
+
+=head2 columns
+
+If data was in a table format, then the column names will be here in the order
+they appeared.
+
+=cut
+
+has 'columns' => ( is => 'rw', isa => ArrayRef[Str] );
+
 =head1 AUTHOR
 
 Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
-1;
\ No newline at end of file
+1;
